﻿;-----------------------------------------------------------------------
; photobooth_greenscreen_backgrounds_by_id.ahk
;
; AutoHotkey script to automatically switch green screen backgrounds and overlays
; when a three digit number is entered using the keyboard number pad.
;
; Usage: Name the green screen backgrounds in the photo booth images folder gs001.jpg,
; gs002.jpg, gs003.jpg etc. Corresponding green screen overlay files, if used, should
; be named gs001.png, gs002.png, gs003.png etc.
; Run this script by double clicking on it in Windows Explorer then enter a three digit
; number using the keyboard number pad keys to switch backgrounds and overlays. Enter
; a non-digit key from the number pad to start entering the id again.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#SingleInstance force
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

; Set this to 0 to turn off the status display or 1 to turn it on
ShowStatus = 1

; Where to place the status text on the screen (0,0=top left corner)
Xpos = 0
Ypos = 0

; Colors
BackgroundColor = Black
TextColor = White

; Create a status window and display it centred at the top of the screen
Gui +LastFound +AlwaysOnTop +ToolWindow -Caption ; +ToolWindow avoids a taskbar button and an alt-tab menu item.
Gui, Color, %BackgroundColor%
Gui, Font, s16 
Gui, Add, Text, vStatusText c%TextColor%, 8888 not found

id :=

Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title not contains ready.jpg
		{
			id :=
			UpdateStatusText(id, 0)
		}
	}
	else
	{
		id :=
		UpdateStatusText(id, 0)
	}
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return

; Only apply macros if photo booth is running
#IfWinExist,Breeze Systems Photobooth -

; Numpad 0 through 9 are used to enter the id
NumPad0::
NumPadIns::
CopyBackground(0)
return

NumPad1::
NumPadEnd::
CopyBackground(1)
return

NumPad2::
NumPadDown::
CopyBackground(2)
return

NumPad3::
NumPadPgDn::
CopyBackground(3)
return

NumPad4::
NumPadLeft::
CopyBackground(4)
return

NumPad5::
NumPadClear::
CopyBackground(5)
return

NumPad6::
NumPadRight::
CopyBackground(6)
return

NumPad7::
NumPadHome::
CopyBackground(7)
return

NumPad8::
NumPadUp::
CopyBackground(8)
return

NumPad9::
NumPadPgUp::
CopyBackground(9)
return

; other numpad keys clear the id
NumPadDot::
NumPadDel::
NumPadEnter::
NumPadDiv::
NumPadMult::
NumPadAdd::
NumPadSub::
id :=
UpdateStatusText(id, 0)
return

CopyBackground(digit)
{
	global id, xPos, yPos

	WinGetTitle,WinTitle,Breeze Systems Photobooth -
	If WinTitle contains video_ready.jpg
	{
		; do nothing if in video booth mode
		return
	}

	; only accept input when the ready.jpg screen is displayed
	If WinTitle contains ready.jpg
	{
		; append the digit to the id entered so far
		id = %id%%digit%
		UpdateStatusText(id, 0)

		; wait for 3 digits to be entered before updating the green screen background/overlay
		if StrLen(id) < 3
		{
			return
		}

		StringLeft, idToLoad, id, 3
		id :=

		; read the location of the photobooth images folder from the photobooth window title
		RegExMatch(WinTitle, "Breeze Systems Photobooth - (.*\\)(.*ready\.jpg)", dir) 

		; work out the names of the background and overlay files
		srcFile = %dir1%gs%idToLoad%.jpg
		destFile = %dir1%greenscreen_background.jpg
		srcOverlayFile = %dir1%gs%idToLoad%.png
		destOverlayFile = %dir1%greenscreen_overlay.png

		; uncomment this line for debug
		;MsgBox, 3-digit idToLoad=%idToLoad%`nbackground=%srcFile%`noverlay=%srcOverlayFile%


		; copy the selected green screen background and overlay files
		IfExist,%srcFile%
		{
			FileCopy,%srcFile%,%destFile%,1	

			; copy overlay file too
			IfExist,%srcOverlayFile%
			{
				FileCopy,%srcOverlayFile%,%destOverlayFile%,1	
			}
			else
			{
				; new background doesn't have an overlay - delete current overlay
				FileDelete,%destOverlayFile%
			}
		
			; display full id
			Sleep,500
			msg = %idToLoad% loaded
			UpdateStatusText(msg, 1000)
		}
		else
		{
			; display error message
			msg = %idToLoad% not found
			UpdateStatusText(msg, 1000)
		}

		; clear the status display ready for the next code to be entered
		UpdateStatusText(id, 0)
	}
}

UpdateStatusText(msg, delay)
{
	global StatusText, ShowStatus, xPos, yPos
	if ShowStatus
	{
		GuiControl,,StatusText,%msg%
		if StrLen(msg) > 0
		{
			IfWinExist, Breeze Systems Photobooth
			{
				WinGetTitle, Title, Breeze Systems Photobooth
				if Title contains ready.jpg
				{
					Gui, Show, x%Xpos% y%Ypos% NA
					Sleep, %delay%
					return
				}
			}
		}
	}
	Gui, Hide
}
